Crate tp_npos_elections_compact

Crate tp_npos_elections_compact 

Proc macro for a npos compact assignment.

Macros

generate_solution_type
Generates a struct to store the election result in a small way. This can encode a structure which is the equivalent of a tp_npos_elections::Assignment<_>.